@@ -8,5 +8,5 @@
 ( cd opt/kde/share/doc/HTML/en/kpackage ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/lilo-config ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/lilo-config ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/knetworkconf ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/knetworkconf ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/knetworkconf ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/knetworkconf ; ln -sf /opt/kde/share/doc/HTML/en/common common )
